@@ -16,10 +16,25 @@ git log --format='%aN' \
    | sort -u \
    | grep -v "^ben$" \
    | grep -v "^bengardner$" \
+   | grep -v "^Ben Gardner$" \
    | grep -v "^CDanU$" \
-   | grep -v "^brmqk3$" \
-   | grep -v "^gmaurel$" \
+   | grep -v "^DVE2000$" \
    | grep -v "^Gilles$" \
+   | grep -v "^Guy Maurel$" \
+   | grep -v "^brmqk3$" \
+   | grep -v "^csobeski$" \
+   | grep -v "^dbeard$" \
+   | grep -v "^gmaurel$" \
+   | grep -v "^hdwobben$" \
+   | grep -v "^ipaterson$" \
+   | grep -v "^jlee975$" \
+   | grep -v "^logan.gauthier@metova.com$" \
+   | grep -v "^nivekkagicom$" \
+   | grep -v "^popipo$" \
+   | grep -v "^raefaldhia$" \
+   | grep -v "^rdan$" \
+   | grep -v "^tpltnt$" \
+   | grep -v "^versusvoid$" \
    | grep -v "^void$" \
       >> ${LIST_1}
 #
