@@ -7,11 +7,14 @@
  * @author  Ben Gardner
  * @license GPL v2+
  */
+
 #include "align_stack.h"
-#include "prototypes.h"
+#include "align_tab_column.h"
 #include "chunk_list.h"
 #include "indent.h"
 #include "space.h"
+#include "prototypes.h"
+#include "uncrustify.h"
 
 #include <limits>
 
@@ -20,14 +23,24 @@ using namespace uncrustify;
 using std::numeric_limits;
 
 
-void AlignStack::Start(size_t span, size_t thresh)
+void AlignStack::Start(size_t span, int thresh)
 {
-   LOG_FMT(LAS, "AlignStack::Start(%d): span is %zu, thresh is %zu\n", __LINE__, span, thresh);
+   LOG_FMT(LAS, "AlignStack::Start(%d): span is %zu, thresh is %d\n", __LINE__, span, thresh);
 
    m_aligned.Reset();
    m_skipped.Reset();
+   if (thresh > 0)
+   {
+      m_absolute_thresh = false;
+      m_thresh          = thresh;
+   }
+   else
+   {
+      m_absolute_thresh = true;
+      m_thresh          = -thresh;
+   }
+
    m_span        = span;
-   m_thresh      = thresh;
    m_min_col     = numeric_limits<size_t>::max();
    m_max_col     = 0;
    m_nl_seqnum   = 0;
@@ -198,8 +211,8 @@ void AlignStack::Add(chunk_t *start, size_t seqnum)
          chunk_t *next = chunk_get_next(tmp);
          if (next != nullptr)
          {
-            LOG_FMT(LAS, "AlignStack::%s(%d): orig_line is %zu, orig_col is %zu, text() '%s'\n",
-                    __func__, __LINE__, next->orig_line, next->orig_col, next->text());
+            LOG_FMT(LAS, "AlignStack::%s(%d): orig_line is %zu, orig_col is %zu, text() '%s', type is %s\n",
+                    __func__, __LINE__, next->orig_line, next->orig_col, next->text(), get_token_name(next->type));
             tmp_col += space_col_align(tmp, next);
             LOG_FMT(LAS, "AlignStack::%s(%d): column is %zu, tmp_col is %zu\n",
                     __func__, __LINE__, next->column, tmp_col);
@@ -216,8 +229,8 @@ void AlignStack::Add(chunk_t *start, size_t seqnum)
    // Check threshold limits
    if (  m_max_col == 0
       || m_thresh == 0
-      || (  ((start->column + m_gap) <= (m_thresh + m_max_col)) // don't use subtraction here to prevent underflow
-         && (  (start->column + m_gap + m_thresh) >= m_max_col  // change the expression to mind negative expression
+      || (  ((start->column + m_gap) <= (m_thresh + (m_absolute_thresh ? m_min_col : m_max_col))) // don't use subtraction here to prevent underflow
+         && (  (start->column + m_gap + m_thresh) >= m_max_col                                    // change the expression to mind negative expression
             || start->column >= m_min_col)))
    {
       // we are adding it, so update the newline seqnum
@@ -258,8 +271,8 @@ void AlignStack::Add(chunk_t *start, size_t seqnum)
       m_aligned.Push_Back(ali, seqnum);
       m_last_added = 1;
 
-      LOG_FMT(LAS, "AlignStack::%s(%d): Add-[%s]: ali->orig_line is %zu, ali->column is %zu\n",
-              __func__, __LINE__, ali->text(), ali->orig_line, ali->column);
+      LOG_FMT(LAS, "AlignStack::%s(%d): Add-[%s]: ali->orig_line is %zu, ali->column is %zu, type is %s\n",
+              __func__, __LINE__, ali->text(), ali->orig_line, ali->column, get_token_name(ali->type));
       LOG_FMT(LAS, "AlignStack::%s(%d):    ali->align.col_adj is %d, ref '%s', endcol is %zu\n",
               __func__, __LINE__, ali->align.col_adj, ref->text(), endcol);
 
@@ -479,7 +492,7 @@ void AlignStack::End()
 {
    if (!m_aligned.Empty())
    {
-      LOG_FMT(LAS, "AlignStack::End-");
+      LOG_FMT(LAS, "AlignStack::End(%d):\n", __LINE__);
       Flush();
    }
 
