@@ -348,7 +348,7 @@ static chunk_t *chunk_ppa_search(chunk_t *cur, const check_t check_fct, const bo
 
    chunk_t *pc = cur;
 
-   while (pc && (pc = pc->next) != nullptr)
+   while (pc != nullptr && (pc = pc->next) != nullptr)
    {
       if (!(pc->flags & PCF_IN_PREPROC))
       {
@@ -447,6 +447,8 @@ chunk_t *chunk_dup(const chunk_t *pc_in)
    {
       // @todo clean up properly before crashing
       LOG_FMT(LERR, "Failed to allocate memory\n");
+      log_func_stack_inline(LSETFLG);
+      log_flush(true);
       exit(EXIT_FAILURE);
    }
 
@@ -476,7 +478,7 @@ static void chunk_log_msg(chunk_t *chunk, const log_sev_t log, const char *str)
    }
    else
    {
-      LOG_FMT(log, "text() '%s', type is %s,", chunk->text(), get_token_name(chunk->type));
+      LOG_FMT(log, "text() is '%s', type is %s,\n", chunk->text(), get_token_name(chunk->type));
    }
 }
 
@@ -493,20 +495,21 @@ static void chunk_log(chunk_t *pc, const char *text)
 
       chunk_log_msg(pc, log, text);
 
-      if (prev && next)
+      if (prev != nullptr && next != nullptr)
       {
          chunk_log_msg(prev, log, " @ between");
          chunk_log_msg(next, log, " and");
       }
-      else if (next)
+      else if (next != nullptr)
       {
          chunk_log_msg(next, log, " @ before");
       }
-      else if (prev)
+      else if (prev != nullptr)
       {
          chunk_log_msg(prev, log, " @ after");
       }
-      LOG_FMT(log, " stage is %u", static_cast<unsigned int>(cpd.unc_stage));
+      LOG_FMT(log, " stage is %s",
+              get_unc_stage_name(cpd.unc_stage));
       log_func_stack_inline(log);
    }
 }
@@ -526,7 +529,7 @@ chunk_t *chunk_add_before(const chunk_t *pc_in, chunk_t *ref)
 
 void chunk_del(chunk_t *pc)
 {
-   chunk_log(pc, "chunk_del:");
+   chunk_log(pc, "chunk_del(B):");
    g_cl.Pop(pc);
    delete pc;
 }
@@ -623,6 +626,12 @@ chunk_t *chunk_get_prev_ncnl(chunk_t *cur, scope_e scope)
 }
 
 
+chunk_t *chunk_get_prev_ncnlni(chunk_t *cur, scope_e scope)
+{
+   return(chunk_search(cur, chunk_is_comment_or_newline_or_ignored, scope, direction_e::BACKWARD, false));
+}
+
+
 chunk_t *chunk_get_prev_nc(chunk_t *cur, scope_e scope)
 {
    return(chunk_search(cur, chunk_is_comment, scope, direction_e::BACKWARD, false));
@@ -888,6 +897,23 @@ static chunk_t *chunk_get_ncnlnp(chunk_t *cur, const scope_e scope, const direct
 
 static chunk_t *chunk_add(const chunk_t *pc_in, chunk_t *ref, const direction_e pos)
 {
+#ifdef DEBUG
+   if (pc_in->orig_line == 0)
+   {
+      fprintf(stderr, "%s(%d): no line number\n", __func__, __LINE__);
+      log_func_stack_inline(LSETFLG);
+      log_flush(true);
+      exit(EX_SOFTWARE);
+   }
+   if (pc_in->orig_col == 0)
+   {
+      fprintf(stderr, "%s(%d): no column number\n", __func__, __LINE__);
+      log_func_stack_inline(LSETFLG);
+      log_flush(true);
+      exit(EX_SOFTWARE);
+   }
+#endif /* DEBUG */
+
    chunk_t *pc = chunk_dup(pc_in);
 
    if (pc != nullptr)
@@ -900,7 +926,7 @@ static chunk_t *chunk_add(const chunk_t *pc_in, chunk_t *ref, const direction_e
       {
          (pos == direction_e::FORWARD) ? g_cl.AddHead(pc) : g_cl.AddTail(pc);
       }
-      chunk_log(pc, "chunk_add:");
+      chunk_log(pc, "chunk_add(A):");
    }
    return(pc);
 }
