@@ -66,11 +66,11 @@ static chunk_tag_t keywords[] =
    { "@implementation",                 CT_OC_IMPL,          LANG_OC                                                                     },
    { "@interface",                      CT_OC_INTF,          LANG_OC                                                                     },
    { "@interface",                      CT_CLASS,            LANG_JAVA                                                                   },
-   { "@private",                        CT_PRIVATE,          LANG_OC                                                                     },
+   { "@private",                        CT_ACCESS,           LANG_OC                                                                     },
    { "@property",                       CT_OC_PROPERTY,      LANG_OC                                                                     },
-   { "@protected",                      CT_PRIVATE,          LANG_OC                                                                     },
+   { "@protected",                      CT_ACCESS,           LANG_OC                                                                     },
    { "@protocol",                       CT_OC_PROTOCOL,      LANG_OC                                                                     },
-   { "@public",                         CT_PRIVATE,          LANG_OC                                                                     },
+   { "@public",                         CT_ACCESS,           LANG_OC                                                                     },
    { "@selector",                       CT_OC_SEL,           LANG_OC                                                                     },
    { "@synchronized",                   CT_SYNCHRONIZED,     LANG_OC                                                                     },
    { "@synthesize",                     CT_OC_DYNAMIC,       LANG_OC                                                                     },
@@ -88,12 +88,14 @@ static chunk_tag_t keywords[] =
    { "Q_FOREVER",                       CT_Q_FOREVER,        LANG_CPP                                                                    }, // guy 2015-10-18
    { "Q_GADGET",                        CT_Q_GADGET,         LANG_CPP                                                                    }, // guy 2016-05-04
    { "Q_OBJECT",                        CT_COMMENT_EMBED,    LANG_CPP                                                                    },
+   { "Q_SIGNALS",                       CT_ACCESS,           LANG_CPP                                                                    },
    { "_Bool",                           CT_TYPE,             LANG_C                                                                      },
    { "_Complex",                        CT_TYPE,             LANG_C                                                                      },
    { "_Imaginary",                      CT_TYPE,             LANG_C                                                                      },
    { "_Nonnull",                        CT_QUALIFIER,        LANG_OC                                                                     },
    { "_Null_unspecified",               CT_QUALIFIER,        LANG_OC                                                                     },
    { "_Nullable",                       CT_QUALIFIER,        LANG_OC                                                                     },
+   { "_Pragma",                         CT_PP_PRAGMA,        LANG_ALL | FLAG_PP                                                          },
    { "__DI__",                          CT_DI,               LANG_C                                                                      },
    { "__HI__",                          CT_HI,               LANG_C                                                                      },
    { "__QI__",                          CT_QI,               LANG_C                                                                      },
@@ -116,6 +118,7 @@ static chunk_tag_t keywords[] =
    { "__nothrow__",                     CT_NOTHROW,          LANG_C                                                                      },
    { "__null_unspecified",              CT_QUALIFIER,        LANG_OC                                                                     },
    { "__nullable",                      CT_QUALIFIER,        LANG_OC                                                                     },
+   { "__pragma",                        CT_PP_PRAGMA,        LANG_ALL | FLAG_PP                                                          },
    { "__restrict",                      CT_QUALIFIER,        LANG_C                                                                      },
    { "__signed__",                      CT_TYPE,             LANG_C                                                                      },
    { "__strong",                        CT_QUALIFIER,        LANG_C                                                                      },
@@ -197,7 +200,7 @@ static chunk_tag_t keywords[] =
    { "error",                           CT_PP_ERROR,         LANG_PAWN | FLAG_PP                                                         }, // PAWN
    { "event",                           CT_TYPE,             LANG_CS                                                                     },
    { "exit",                            CT_FUNCTION,         LANG_PAWN                                                                   }, // PAWN
-   { "explicit",                        CT_TYPE,             LANG_CPP | LANG_CS                                                          },
+   { "explicit",                        CT_QUALIFIER,        LANG_CPP | LANG_CS                                                          },
    { "export",                          CT_EXPORT,           LANG_CPP | LANG_D | LANG_ECMA                                               },
    { "extends",                         CT_QUALIFIER,        LANG_JAVA | LANG_ECMA                                                       },
    { "extern",                          CT_EXTERN,           LANG_C | LANG_CS | LANG_D | LANG_VALA                                       },
@@ -263,14 +266,14 @@ static chunk_tag_t keywords[] =
    { "or_eq",                           CT_SASSIGN,          LANG_CPP                                                                    },
    { "out",                             CT_QUALIFIER,        LANG_CS | LANG_D | LANG_VALA                                                },
    { "override",                        CT_QUALIFIER,        LANG_CPP | LANG_CS | LANG_D | LANG_VALA                                     },
-   { "package",                         CT_PRIVATE,          LANG_D                                                                      },
+   { "package",                         CT_ACCESS,           LANG_D                                                                      },
    { "package",                         CT_PACKAGE,          LANG_ECMA | LANG_JAVA                                                       },
    { "params",                          CT_TYPE,             LANG_CS | LANG_VALA                                                         },
-   { "pragma",                          CT_PP_PRAGMA,        LANG_ALL | FLAG_PP                                                          }, // PAWN
-   { "private",                         CT_PRIVATE,          LANG_ALLC                                                                   }, // not C
+   { "pragma",                          CT_PP_PRAGMA,        LANG_ALL | FLAG_PP                                                          },
+   { "private",                         CT_ACCESS,           LANG_ALLC                                                                   }, // not C
    { "property",                        CT_PP_PROPERTY,      LANG_CS | FLAG_PP                                                           },
-   { "protected",                       CT_PRIVATE,          LANG_ALLC                                                                   }, // not C
-   { "public",                          CT_PRIVATE,          LANG_ALL                                                                    }, // PAWN // not C
+   { "protected",                       CT_ACCESS,           LANG_ALLC                                                                   }, // not C
+   { "public",                          CT_ACCESS,           LANG_ALL                                                                    }, // PAWN // not C
    { "readonly",                        CT_QUALIFIER,        LANG_CS                                                                     },
    { "real",                            CT_TYPE,             LANG_D                                                                      },
    { "ref",                             CT_QUALIFIER,        LANG_CS | LANG_VALA                                                         },
@@ -287,8 +290,8 @@ static chunk_tag_t keywords[] =
    { "self",                            CT_THIS,             LANG_OC                                                                     },
    { "set",                             CT_GETSET,           LANG_CS | LANG_VALA                                                         },
    { "short",                           CT_TYPE,             LANG_ALLC                                                                   },
-   { "signal",                          CT_PRIVATE,          LANG_VALA                                                                   },
-   { "signals",                         CT_PRIVATE,          LANG_CPP                                                                    },
+   { "signal",                          CT_ACCESS,           LANG_VALA                                                                   },
+   { "signals",                         CT_ACCESS,           LANG_CPP                                                                    },
    { "signed",                          CT_TYPE,             LANG_C                                                                      },
    { "sizeof",                          CT_SIZEOF,           LANG_C | LANG_CS | LANG_VALA | LANG_PAWN                                    }, // PAWN
    { "sleep",                           CT_SIZEOF,           LANG_PAWN                                                                   }, // PAWN
@@ -493,6 +496,10 @@ c_token_t find_keyword_type(const char *word, size_t len)
 
    if (p_ret != nullptr)
    {
+      if (strcmp(p_ret->tag, "__pragma") == 0 || strcmp(p_ret->tag, "_Pragma") == 0)
+      {
+         cpd.in_preproc = CT_PREPROC;
+      }
       p_ret = kw_static_match(p_ret, cpd.lang_flags);
    }
    return((p_ret != nullptr) ? p_ret->type : CT_WORD);
