@@ -10,6 +10,10 @@
 
 #include "uncrustify_types.h"
 
+/**
+ * Initializes keywords table
+ */
+void init_keywords(void);
 
 /**
  * Loads the dynamic keywords from a file
@@ -39,15 +43,7 @@ c_token_t find_keyword_type(const char *word, size_t len);
  * @param tag   The tag (string) must be zero terminated
  * @param type  The type, usually CT_TYPE
  */
-void add_keyword(const char *tag, c_token_t type);
-
-
-/*
- * Removes a keyword from the list of dynamic keywords
- *
- * @param tag        The tag (string)
- */
-void remove_keyword(const std::string &tag);
+void add_keyword(const std::string &tag, c_token_t type);
 
 
 void print_keywords(FILE *pfile);
