@@ -8,6 +8,7 @@
  * @license GPL v2+
  */
 #include "output.h"
+#include "align_tab_column.h"
 #include "uncrustify_types.h"
 #include "prototypes.h"
 #include "chunk_list.h"
@@ -277,12 +278,15 @@ static void add_char(UINT32 ch, bool is_literal)
       // explicitly disallow a tab after a space
       if (!is_literal && ch == '\t' && cpd.last_char == ' ')
       {
-         size_t endcol = next_tab_column(cpd.column);
-         while (cpd.column < endcol)
+         if (options::indent_with_tabs() == 0)
          {
-            add_char(' ');
+            size_t endcol = next_tab_column(cpd.column);
+            while (cpd.column < endcol)
+            {
+               add_char(' ');
+            }
+            return;
          }
-         return;
       }
 
       if ((ch == ' ') && !cpd.output_trailspace)
@@ -425,15 +429,29 @@ void output_parsed(FILE *pfile)
    // output.cpp, line 427: fprintf(pfile, "# Line              Tag                Parent...
    // and              430: ... fprintf(pfile, "%s# %3zu>%19.19s[%19.19s] ...
    // here                                                xx xx   xx xx
+#ifdef WIN32
+   fprintf(pfile, "# Line                Tag              Parent          Columns Br/Lvl/pp     Nl  Text");
+#else // not WIN32
    fprintf(pfile, "# Line                Tag              Parent          Columns Br/Lvl/pp     Flag   Nl  Text");
+#endif // ifdef WIN32
    for (chunk_t *pc = chunk_get_head(); pc != nullptr; pc = chunk_get_next(pc))
    {
-      fprintf(pfile, "%s# %3zu>%19.19s[%19.19s][%3zu/%3zu/%3zu/%3d][%zu/%zu/%zu][%10" PRIx64 "][%zu-%d]",
+#ifdef WIN32
+      fprintf(pfile, "%s# %3d>%19.19s[%19.19s][%3d/%3d/%3d/%3d][%d/%d/%d][%d-%d]",
+              eol_marker, (int)pc->orig_line, get_token_name(pc->type), get_token_name(pc->parent_type),
+              (int)pc->column, (int)pc->orig_col, (int)pc->orig_col_end, (int)pc->orig_prev_sp,
+              (int)pc->brace_level, (int)pc->level, (int)pc->pp_level, (int)pc->nl_count, pc->after_tab);
+#else // not WIN32
+      fprintf(pfile, "%s# %3zu>%19.19s[%19.19s][%3zu/%3zu/%3zu/%3d][%zu/%zu/%zu]",
               eol_marker, pc->orig_line, get_token_name(pc->type),
               get_token_name(pc->parent_type),
               pc->column, pc->orig_col, pc->orig_col_end, pc->orig_prev_sp,
-              pc->brace_level, pc->level, pc->pp_level,
-              pc->flags, pc->nl_count, pc->after_tab);
+              pc->brace_level, pc->level, pc->pp_level);
+      fprintf(pfile, "[%10" PRIx64 "]",
+              pc->flags);
+      fprintf(pfile, "[%zu-%d]",
+              pc->nl_count, pc->after_tab);
+#endif // ifdef WIN32
 
       if (pc->type != CT_NEWLINE && (pc->len() != 0))
       {
@@ -494,7 +512,7 @@ void output_text(FILE *pfile)
          {
             if (cnt > 0 && pc->nl_column > 1)
             {
-               output_to_column(pc->nl_column, false);
+               output_to_column(pc->nl_column, (options::indent_with_tabs() == 2));
             }
             add_char('\n');
          }
@@ -540,8 +558,13 @@ void output_text(FILE *pfile)
                      int orig_sp = (pc->orig_col - prev->orig_col_end);
                      if ((int)(cpd.column + orig_sp) < 0)
                      {
-                        fprintf(stderr, "FATAL: negative value.\n   pc->orig_col=%zu prev->orig_col_end=%zu\n",
+#ifdef WIN32
+                        fprintf(stderr, "FATAL: negative value.\n   pc->orig_col is %d, prev->orig_col_end is %d\n",
+                                (int)pc->orig_col, (int)prev->orig_col_end);
+#else // not WIN32
+                        fprintf(stderr, "FATAL: negative value.\n   pc->orig_col is %zu, prev->orig_col_end is %zu\n",
                                 pc->orig_col, prev->orig_col_end);
+#endif // ifdef WIN32
                         log_flush(true);
                         exit(EX_SOFTWARE);
                      }
@@ -603,7 +626,8 @@ void output_text(FILE *pfile)
       else if (pc->len() == 0)
       {
          // don't do anything for non-visible stuff
-         LOG_FMT(LOUTIND, " <%zu> -", pc->column);
+         LOG_FMT(LOUTIND, "%s(%d): orig_line is %zu, column is %zu, non-visible stuff: type is %s\n",
+                 __func__, __LINE__, pc->orig_line, pc->column, get_token_name(pc->type));
       }
       else
       {
