@@ -11,6 +11,7 @@
 #include "ChunkStack.h"
 #include "prototypes.h"
 #include "uncrustify.h"
+#include "language_tools.h"
 
 #include <cstdio>
 #include <cstdlib>
@@ -32,8 +33,8 @@ static void check_unknown_brace_close(chunk_t *semi, chunk_t *brace_close);
 static void remove_semicolon(chunk_t *pc)
 {
    LOG_FUNC_ENTRY();
-   LOG_FMT(LDELSEMI, "%s: Removed semicolon at line %zu, col %zu",
-           __func__, pc->orig_line, pc->orig_col);
+   LOG_FMT(LDELSEMI, "%s(%d): Removed semicolon: orig_line is %zu, orig_col is %zu",
+           __func__, __LINE__, pc->orig_line, pc->orig_col);
    log_func_stack_inline(LDELSEMI);
    // TODO: do we want to shift stuff back a column?
    chunk_del(pc);
@@ -49,12 +50,12 @@ void remove_extra_semicolons(void)
    {
       chunk_t *next = chunk_get_next_ncnl(pc);
       chunk_t *prev;
-      if (  pc->type == CT_SEMICOLON
+      if (  chunk_is_token(pc, CT_SEMICOLON)
          && !(pc->flags & PCF_IN_PREPROC)
          && (prev = chunk_get_prev_ncnl(pc)) != nullptr)
       {
-         LOG_FMT(LSCANSEMI, "Semi on %zu:%zu parent=%s, prev = '%s' [%s/%s]\n",
-                 pc->orig_line, pc->orig_col, get_token_name(pc->parent_type),
+         LOG_FMT(LSCANSEMI, "%s(%d): Semi orig_line is %zu, orig_col is %zu, parent is %s, prev = '%s' [%s/%s]\n",
+                 __func__, __LINE__, pc->orig_line, pc->orig_col, get_token_name(pc->parent_type),
                  prev->text(),
                  get_token_name(prev->type), get_token_name(prev->parent_type));
 
@@ -62,7 +63,7 @@ void remove_extra_semicolons(void)
          {
             // keep it
          }
-         else if (  prev->type == CT_BRACE_CLOSE
+         else if (  chunk_is_token(prev, CT_BRACE_CLOSE)
                  && (  prev->parent_type == CT_IF
                     || prev->parent_type == CT_ELSEIF
                     || prev->parent_type == CT_ELSE
@@ -78,17 +79,17 @@ void remove_extra_semicolons(void)
             LOG_FUNC_CALL();
             remove_semicolon(pc);
          }
-         else if (  prev->type == CT_BRACE_CLOSE
+         else if (  chunk_is_token(prev, CT_BRACE_CLOSE)
                  && prev->parent_type == CT_NONE)
          {
             check_unknown_brace_close(pc, prev);
          }
-         else if (prev->type == CT_SEMICOLON && prev->parent_type != CT_FOR)
+         else if (chunk_is_token(prev, CT_SEMICOLON) && prev->parent_type != CT_FOR)
          {
             LOG_FUNC_CALL();
             remove_semicolon(pc);
          }
-         else if (  (cpd.lang_flags & LANG_D)
+         else if (  language_is_set(LANG_D)
                  && (  prev->parent_type == CT_ENUM
                     || prev->parent_type == CT_UNION
                     || prev->parent_type == CT_STRUCT))
@@ -96,13 +97,13 @@ void remove_extra_semicolons(void)
             LOG_FUNC_CALL();
             remove_semicolon(pc);
          }
-         else if (  (cpd.lang_flags & LANG_JAVA)
+         else if (  language_is_set(LANG_JAVA)
                  && prev->parent_type == CT_SYNCHRONIZED)
          {
             LOG_FUNC_CALL();
             remove_semicolon(pc);
          }
-         else if (prev->type == CT_BRACE_OPEN)
+         else if (chunk_is_token(prev, CT_BRACE_OPEN))
          {
             LOG_FUNC_CALL();
             remove_semicolon(pc);
