@@ -10,16 +10,20 @@
 #include "prototypes.h"
 #include <regex>
 
+using namespace uncrustify;
 
-enum
-{
-   kIncludeCategoriesCount = UO_include_category_last - UO_include_category_first + 1,
+
+Option<std::string>  *include_category_options[] = {
+   &options::include_category_0,
+   &options::include_category_1,
+   &options::include_category_2,
 };
+constexpr static int kIncludeCategoriesCount = 3;
 
 
 struct include_category
 {
-   include_category(const char *pattern)
+   include_category(const std::string &pattern)
       : regex(pattern)
    {
    }
@@ -50,11 +54,10 @@ static void do_the_sort(chunk_t **chunks, size_t num_chunks);
 
 static void prepare_categories()
 {
-   for (int i = 0; i < kIncludeCategoriesCount; i++)
+   for (int i = 0; i < kIncludeCategoriesCount; ++i)
    {
-      const auto *cat_pattern = cpd.settings[UO_include_category_first + i].str;
-
-      if (cat_pattern != nullptr && cat_pattern[0] != '\0')
+      const auto &cat_pattern = (*include_category_options[i])();
+      if (!cat_pattern.empty())
       {
          include_categories[i] = new include_category(cat_pattern);
       }
@@ -136,14 +139,14 @@ static int compare_chunks(chunk_t *pc1, chunk_t *pc2)
       // Same word, same length. Step to the next chunk.
       pc1 = chunk_get_next(pc1);
       LOG_FMT(LSORT, "text=%s, pc1->len=%zu, line=%zu, column=%zu\n", pc1->text(), pc1->len(), pc1->orig_line, pc1->orig_col);
-      if (pc1->type == CT_MEMBER)
+      if (chunk_is_token(pc1, CT_MEMBER))
       {
          pc1 = chunk_get_next(pc1);
          LOG_FMT(LSORT, "text=%s, pc1->len=%zu, line=%zu, column=%zu\n", pc1->text(), pc1->len(), pc1->orig_line, pc1->orig_col);
       }
       pc2 = chunk_get_next(pc2);
       LOG_FMT(LSORT, "text=%s, pc2->len=%zu, line=%zu, column=%zu\n", pc2->text(), pc2->len(), pc2->orig_line, pc2->orig_col);
-      if (pc2->type == CT_MEMBER)
+      if (chunk_is_token(pc2, CT_MEMBER))
       {
          pc2 = chunk_get_next(pc2);
          LOG_FMT(LSORT, "text=%s, pc2->len=%zu, line=%zu, column=%zu\n", pc2->text(), pc2->len(), pc2->orig_line, pc2->orig_col);
@@ -235,7 +238,7 @@ void sort_imports(void)
 
          if (  p_imp != nullptr
             && p_last != nullptr
-            && (  p_last->type == CT_SEMICOLON
+            && (  chunk_is_token(p_last, CT_SEMICOLON)
                || (p_imp->flags & PCF_IN_PREPROC)))
          {
             if (num_chunks < MAX_NUMBER_TO_SORT)
@@ -266,23 +269,23 @@ void sort_imports(void)
          p_imp  = nullptr;
          p_last = nullptr;
       }
-      else if (pc->type == CT_IMPORT)
+      else if (chunk_is_token(pc, CT_IMPORT))
       {
-         if (cpd.settings[UO_mod_sort_import].b)
+         if (options::mod_sort_import())
          {
             p_imp = chunk_get_next(pc);
          }
       }
-      else if (pc->type == CT_USING)
+      else if (chunk_is_token(pc, CT_USING))
       {
-         if (cpd.settings[UO_mod_sort_using].b)
+         if (options::mod_sort_using())
          {
             p_imp = chunk_get_next(pc);
          }
       }
-      else if (pc->type == CT_PP_INCLUDE)
+      else if (chunk_is_token(pc, CT_PP_INCLUDE))
       {
-         if (cpd.settings[UO_mod_sort_include].b)
+         if (options::mod_sort_include())
          {
             p_imp  = chunk_get_next(pc);
             p_last = pc;
