@@ -80,41 +80,41 @@ struct no_space_table_t
  */
 const no_space_table_t no_space_table[] =
 {
-   { CT_OC_AT,          CT_UNKNOWN       },
-   { CT_INCDEC_BEFORE,  CT_WORD          },
-   { CT_UNKNOWN,        CT_INCDEC_AFTER  },
-   { CT_UNKNOWN,        CT_LABEL_COLON   },
-   { CT_UNKNOWN,        CT_PRIVATE_COLON },
-   { CT_UNKNOWN,        CT_SEMICOLON     },
-   { CT_UNKNOWN,        CT_D_TEMPLATE    },
-   { CT_D_TEMPLATE,     CT_UNKNOWN       },
-   { CT_MACRO_FUNC,     CT_FPAREN_OPEN   },
-   { CT_PAREN_OPEN,     CT_UNKNOWN       },
-   { CT_UNKNOWN,        CT_PAREN_CLOSE   },
-   { CT_FPAREN_OPEN,    CT_UNKNOWN       },
-   { CT_UNKNOWN,        CT_SPAREN_CLOSE  },
-   { CT_SPAREN_OPEN,    CT_UNKNOWN       },
-   { CT_UNKNOWN,        CT_FPAREN_CLOSE  },
-   { CT_UNKNOWN,        CT_COMMA         },
-   { CT_POS,            CT_UNKNOWN       },
-   { CT_STAR,           CT_UNKNOWN       },
-   { CT_VBRACE_CLOSE,   CT_UNKNOWN       },
-   { CT_VBRACE_OPEN,    CT_UNKNOWN       },
-   { CT_UNKNOWN,        CT_VBRACE_CLOSE  },
-   { CT_UNKNOWN,        CT_VBRACE_OPEN   },
-   { CT_PREPROC,        CT_UNKNOWN       },
-   { CT_PREPROC_INDENT, CT_UNKNOWN       },
-   { CT_NEG,            CT_UNKNOWN       },
-   { CT_UNKNOWN,        CT_SQUARE_OPEN   },
-   { CT_UNKNOWN,        CT_SQUARE_CLOSE  },
-   { CT_SQUARE_OPEN,    CT_UNKNOWN       },
-   { CT_PAREN_CLOSE,    CT_WORD          },
-   { CT_PAREN_CLOSE,    CT_FUNC_DEF      },
-   { CT_PAREN_CLOSE,    CT_FUNC_CALL     },
-   { CT_PAREN_CLOSE,    CT_ADDR          },
-   { CT_PAREN_CLOSE,    CT_FPAREN_OPEN   },
-   { CT_OC_SEL_NAME,    CT_OC_SEL_NAME   },
-   { CT_TYPENAME,       CT_TYPE          },
+   { CT_OC_AT,          CT_UNKNOWN      },
+   { CT_INCDEC_BEFORE,  CT_WORD         },
+   { CT_UNKNOWN,        CT_INCDEC_AFTER },
+   { CT_UNKNOWN,        CT_LABEL_COLON  },
+   { CT_UNKNOWN,        CT_ACCESS_COLON },
+   { CT_UNKNOWN,        CT_SEMICOLON    },
+   { CT_UNKNOWN,        CT_D_TEMPLATE   },
+   { CT_D_TEMPLATE,     CT_UNKNOWN      },
+   { CT_MACRO_FUNC,     CT_FPAREN_OPEN  },
+   { CT_PAREN_OPEN,     CT_UNKNOWN      },
+   { CT_UNKNOWN,        CT_PAREN_CLOSE  },
+   { CT_FPAREN_OPEN,    CT_UNKNOWN      },
+   { CT_UNKNOWN,        CT_SPAREN_CLOSE },
+   { CT_SPAREN_OPEN,    CT_UNKNOWN      },
+   { CT_UNKNOWN,        CT_FPAREN_CLOSE },
+   { CT_UNKNOWN,        CT_COMMA        },
+   { CT_POS,            CT_UNKNOWN      },
+   { CT_STAR,           CT_UNKNOWN      },
+   { CT_VBRACE_CLOSE,   CT_UNKNOWN      },
+   { CT_VBRACE_OPEN,    CT_UNKNOWN      },
+   { CT_UNKNOWN,        CT_VBRACE_CLOSE },
+   { CT_UNKNOWN,        CT_VBRACE_OPEN  },
+   { CT_PREPROC,        CT_UNKNOWN      },
+   { CT_PREPROC_INDENT, CT_UNKNOWN      },
+   { CT_NEG,            CT_UNKNOWN      },
+   { CT_UNKNOWN,        CT_SQUARE_OPEN  },
+   { CT_UNKNOWN,        CT_SQUARE_CLOSE },
+   { CT_SQUARE_OPEN,    CT_UNKNOWN      },
+   { CT_PAREN_CLOSE,    CT_WORD         },
+   { CT_PAREN_CLOSE,    CT_FUNC_DEF     },
+   { CT_PAREN_CLOSE,    CT_FUNC_CALL    },
+   { CT_PAREN_CLOSE,    CT_ADDR         },
+   { CT_PAREN_CLOSE,    CT_FPAREN_OPEN  },
+   { CT_OC_SEL_NAME,    CT_OC_SEL_NAME  },
+   { CT_TYPENAME,       CT_TYPE         },
 };
 
 #define log_rule(rule)                                   \
@@ -350,10 +350,15 @@ static iarf_e do_space(chunk_t *first, chunk_t *second, int &min_sp)
    {
       if (second->parent_type == CT_FOR)
       {
-         if (  (options::sp_before_semi_for_empty() != IARF_IGNORE)
-            && (  chunk_is_token(first, CT_SPAREN_OPEN)
-               || chunk_is_token(first, CT_SEMICOLON)))
+         if (  chunk_is_token(first, CT_SPAREN_OPEN) // a
+            || chunk_is_token(first, CT_SEMICOLON))  // b
          {
+            // empty, ie for (;;)
+            //               ^ is first    // a
+            //                ^ is second  // a
+            // or
+            //                ^ is first   // b
+            //                 ^ is second // b
             log_rule("sp_before_semi_for_empty");
             return(options::sp_before_semi_for_empty());
          }
@@ -540,7 +545,7 @@ static iarf_e do_space(chunk_t *first, chunk_t *second, int &min_sp)
       case CT_SARITH:
       case CT_SCOMPARE:
       case CT_OPERATOR:
-      case CT_PRIVATE:
+      case CT_ACCESS:
       case CT_QUALIFIER:
       case CT_RETURN:
       case CT_SIZEOF:
@@ -707,6 +712,15 @@ static iarf_e do_space(chunk_t *first, chunk_t *second, int &min_sp)
       return(options::sp_oc_catch_paren());
    }
 
+   if (  language_is_set(LANG_OC)
+      && chunk_is_token(first, CT_OC_CLASS)
+      && chunk_is_token(second, CT_PAREN_OPEN)
+      && (options::sp_oc_classname_paren() != IARF_IGNORE))
+   {
+      log_rule("sp_oc_classname_paren");
+      return(options::sp_oc_classname_paren());
+   }
+
    if (  chunk_is_token(first, CT_CATCH)
       && chunk_is_token(second, CT_SPAREN_OPEN)
       && (options::sp_catch_paren() != IARF_IGNORE))
@@ -812,6 +826,23 @@ static iarf_e do_space(chunk_t *first, chunk_t *second, int &min_sp)
       return(options::sp_assign());
    }
 
+   if (chunk_is_token(second, CT_ASSIGN_DEFAULT_ARG))
+   {
+      if (  (options::sp_assign_default() != IARF_IGNORE)
+         && second->parent_type == CT_FUNC_PROTO)
+      {
+         log_rule("sp_assign_default");
+         return(options::sp_assign_default());
+      }
+      if (options::sp_before_assign() != IARF_IGNORE)
+      {
+         log_rule("sp_before_assign");
+         return(options::sp_before_assign());
+      }
+      log_rule("sp_assign");
+      return(options::sp_assign());
+   }
+
    if (chunk_is_token(first, CT_ASSIGN))
    {
       if (first->flags & PCF_IN_ENUM)
@@ -839,6 +870,23 @@ static iarf_e do_space(chunk_t *first, chunk_t *second, int &min_sp)
       return(options::sp_assign());
    }
 
+   if (chunk_is_token(first, CT_ASSIGN_DEFAULT_ARG))
+   {
+      if (  (options::sp_assign_default() != IARF_IGNORE)
+         && first->parent_type == CT_FUNC_PROTO)
+      {
+         log_rule("sp_assign_default");
+         return(options::sp_assign_default());
+      }
+      if (options::sp_after_assign() != IARF_IGNORE)
+      {
+         log_rule("sp_after_assign");
+         return(options::sp_after_assign());
+      }
+      log_rule("sp_assign");
+      return(options::sp_assign());
+   }
+
    if (chunk_is_token(first, CT_BIT_COLON))
    {
       if (first->flags & PCF_IN_ENUM)
@@ -928,8 +976,17 @@ static iarf_e do_space(chunk_t *first, chunk_t *second, int &min_sp)
    }
 
    // spacing around template < > stuff
-   if (chunk_is_token(first, CT_ANGLE_OPEN) || chunk_is_token(second, CT_ANGLE_CLOSE))
+   if (  chunk_is_token(first, CT_ANGLE_OPEN)
+      || chunk_is_token(second, CT_ANGLE_CLOSE))
    {
+      if (  chunk_is_token(first, CT_ANGLE_OPEN)
+         && chunk_is_token(second, CT_ANGLE_CLOSE))
+      {
+         log_rule("sp_inside_angle_empty");
+
+         return(options::sp_inside_angle_empty());
+      }
+
       log_rule("sp_inside_angle");
 
       iarf_e op = options::sp_inside_angle();
@@ -1102,6 +1159,20 @@ static iarf_e do_space(chunk_t *first, chunk_t *second, int &min_sp)
       return(options::sp_after_operator_sym());
    }
 
+   // Issue #2270
+   // Translations under vala
+   if (  language_is_set(LANG_VALA)
+      && chunk_is_token(first, CT_FUNC_CALL))
+   {
+      if (  chunk_is_str(first, "_", 1)
+         && chunk_is_token(second, CT_FPAREN_OPEN)
+         && (options::sp_vala_after_translation() != IARF_IGNORE))
+      {
+         log_rule("sp_vala_after_translation");
+         return(options::sp_vala_after_translation());
+      }
+   }
+
    // spaces between function and open paren
    if (  chunk_is_token(first, CT_FUNC_CALL)
       || chunk_is_token(first, CT_FUNC_CTOR_VAR)
@@ -1152,7 +1223,7 @@ static iarf_e do_space(chunk_t *first, chunk_t *second, int &min_sp)
       return(options::sp_cpp_cast_paren());
    }
 
-   if (chunk_is_token(first, CT_PAREN_CLOSE) && chunk_is_token(second, CT_WHEN))
+   if (chunk_is_token(first, CT_SPAREN_CLOSE) && chunk_is_token(second, CT_WHEN))
    {
       log_rule("FORCE");
       return(IARF_FORCE); // TODO: make this configurable?
@@ -2017,12 +2088,19 @@ static iarf_e do_space(chunk_t *first, chunk_t *second, int &min_sp)
       return(options::sp_after_type());
    }
 
+   if (  language_is_set(LANG_VALA)
+      && chunk_is_token(second, CT_QUESTION))
+   {
+      // Issue #2090
+      log_rule("sp_type_question");
+      return(options::sp_type_question());
+   }
    if (  !chunk_is_token(second, CT_PTR_TYPE)
       && (chunk_is_token(first, CT_QUALIFIER) || chunk_is_token(first, CT_TYPE)))
    {
       iarf_e arg = options::sp_after_type();
       log_rule("sp_after_type");
-      return((arg != IARF_REMOVE) ? arg : IARF_FORCE);
+      return(arg);
    }
 
    if (  chunk_is_token(first, CT_MACRO_OPEN)
@@ -2130,12 +2208,6 @@ static iarf_e do_space(chunk_t *first, chunk_t *second, int &min_sp)
       return(IARF_FORCE);
    }
 
-   if (chunk_is_comment(second))
-   {
-      log_rule("IGNORE");
-      return(IARF_IGNORE);
-   }
-
    if (chunk_is_token(first, CT_COMMENT))
    {
       log_rule("FORCE");
@@ -2200,6 +2272,37 @@ static iarf_e do_space(chunk_t *first, chunk_t *second, int &min_sp)
       return(options::sp_after_noexcept());
    }
 
+   // Issue #2138
+   if (chunk_is_token(first, CT_FPAREN_CLOSE))
+   {
+      if (chunk_is_token(second, CT_QUALIFIER))
+      {
+         log_rule("sp_paren_qualifier");
+         return(options::sp_paren_qualifier());
+      }
+      else if (chunk_is_token(second, CT_NOEXCEPT))
+      {
+         log_rule("sp_paren_noexcept");
+         return(options::sp_paren_noexcept());
+      }
+   }
+
+   // Issue #2098
+   if (  chunk_is_token(first, CT_PP_PRAGMA)
+      && chunk_is_token(second, CT_PREPROC_BODY))
+   {
+      log_rule("REMOVE");
+      return(IARF_REMOVE);
+   }
+
+   // Issue #1733
+   if (  chunk_is_token(first, CT_OPERATOR_VAL)
+      && chunk_is_token(second, CT_TYPE))
+   {
+      log_rule("IGNORE");
+      return(IARF_IGNORE);
+   }
+
    // these lines are only useful for debugging uncrustify itself
    D_LOG_FMT(LSPACE, "\n\n%s(%d): WARNING: unrecognize do_space:\n",
              __func__, __LINE__);
@@ -2382,7 +2485,7 @@ void space_text(void)
                       */
                      if (  (  (  language_is_set(LANG_CPP)
                               && options::sp_permit_cpp11_shift())
-                           || (language_is_set(LANG_JAVA | LANG_CS)))
+                           || (language_is_set(LANG_JAVA | LANG_CS | LANG_VALA)))
                         && chunk_is_token(pc, CT_ANGLE_CLOSE)
                         && chunk_is_token(next, CT_ANGLE_CLOSE))
                      {
@@ -2474,8 +2577,11 @@ void space_text(void)
                if (options::indent_relative_single_line_comments())
                {
                   // Try to keep relative spacing between tokens
-                  LOG_FMT(LSPACE, " <relative adj>");
-                  column = pc->column + 1 + (next->orig_col - pc->orig_col_end);
+                  LOG_FMT(LSPACE, "%s(%d): <relative adj>", __func__, __LINE__);
+                  LOG_FMT(LSPACE, "%s(%d): pc is '%s', pc->orig_col is %zu, next->orig_col is %zu, pc->orig_col_end is %zu\n",
+                          __func__, __LINE__, pc->text(),
+                          pc->orig_col, next->orig_col, pc->orig_col_end);
+                  column = pc->column + (next->orig_col - pc->orig_col_end);
                }
                else
                {
@@ -2489,13 +2595,13 @@ void space_text(void)
                   {
                      column = col_min;
                   }
-                  LOG_FMT(LSPACE, " <relative set>");
+                  LOG_FMT(LSPACE, "%s(%d): <relative set>", __func__, __LINE__);
                }
             }
          }
          next->column = column;
 
-         LOG_FMT(LSPACE, "%s(%d): rule = %s @ %zu => %zu\n", __func__, __LINE__,
+         LOG_FMT(LSPACE, " rule = %s @ %zu => %zu\n",
                  (av == IARF_IGNORE) ? "IGNORE" :
                  (av == IARF_ADD) ? "ADD" :
                  (av == IARF_REMOVE) ? "REMOVE" : "FORCE",
@@ -2535,20 +2641,11 @@ void space_text_balance_nested_parens(void)
          // insert a space between them
          space_add_after(first, 1);
 
-         /*
-          * find the closing paren that matches the 'first' open paren and force
-          * a space before it
-          */
-         chunk_t *cur  = next;
-         chunk_t *prev = cur;
-         while ((cur = chunk_get_next(cur)) != nullptr) // find the closing parenthesis
-         {                                              // that matches the
-            if (cur->level == first->level)             // first open parenthesis
-            {
-               space_add_after(prev, 1);                // and force a space before it
-               break;
-            }
-            prev = cur;
+         // test after the closing parens   Issue #1703
+         chunk_t *closing = chunk_get_next_type(first, (c_token_t)(first->type + 1), first->level);
+         if (closing->orig_col == closing->prev->orig_col_end)
+         {
+            space_add_after(closing->prev, 1);
          }
       }
       else if (chunk_is_str(first, ")", 1) && chunk_is_str(next, ")", 1))
@@ -2556,20 +2653,12 @@ void space_text_balance_nested_parens(void)
          // insert a space between the two closing parens
          space_add_after(first, 1);
 
-         // issue # 752
-         // the next lines are never used in the tests.
-         // TODO: why that?
-         ///* find the opening paren that matches the 'next' close paren and force
-         // * a space after it */
-         //cur = first;
-         //while ((cur = chunk_get_prev(cur)) != nullptr)
-         //{
-         //   if (cur->level == next->level)
-         //   {
-         //      //space_add_after(cur, 1);
-         //      break;
-         //   }
-         //}
+         // test after the opening parens   Issue #1703
+         chunk_t *opening = chunk_get_prev_type(next, (c_token_t)(next->type - 1), next->level);
+         if (opening->orig_col_end == opening->next->orig_col)
+         {
+            space_add_after(opening, 1);
+         }
       }
 
       first = next;
@@ -2603,11 +2692,12 @@ size_t space_col_align(chunk_t *first, chunk_t *second)
 {
    LOG_FUNC_ENTRY();
 
-   LOG_FMT(LSPACE, "%s(%d): orig_line is %zu, orig_col is %zu, [%s/%s] '%s' <==> orig_line is %zu, orig_col is %zu [%s/%s] '%s'",
+   LOG_FMT(LSPACE, "%s(%d): first->orig_line is %zu, orig_col is %zu, [%s/%s], text() '%s' <==>\n",
            __func__, __LINE__, first->orig_line, first->orig_col,
            get_token_name(first->type), get_token_name(first->parent_type),
-           first->text(),
-           second->orig_line, second->orig_col,
+           first->text());
+   LOG_FMT(LSPACE, "%s(%d): second->orig_line is %zu, orig_col is %zu [%s/%s], text() '%s',",
+           __func__, __LINE__, second->orig_line, second->orig_col,
            get_token_name(second->type), get_token_name(second->parent_type),
            second->text());
    log_func_stack_inline(LSPACE);
@@ -2619,15 +2709,20 @@ size_t space_col_align(chunk_t *first, chunk_t *second)
    size_t coldiff;
    if (first->nl_count)
    {
-      LOG_FMT(LSPACE, "   nl_count is %zu, orig_col_end is %zu\n", first->nl_count, first->orig_col_end);
+      LOG_FMT(LSPACE, "%s(%d):    nl_count is %zu, orig_col_end is %zu\n", __func__, __LINE__, first->nl_count, first->orig_col_end);
       coldiff = first->orig_col_end - 1;
    }
    else
    {
-      LOG_FMT(LSPACE, "   len is %zu\n", first->len());
+      LOG_FMT(LSPACE, "%s(%d):    len is %zu\n", __func__, __LINE__, first->len());
       coldiff = first->len();
    }
+   LOG_FMT(LSPACE, "%s(%d):    => coldiff is %zu\n", __func__, __LINE__, coldiff);
 
+   LOG_FMT(LSPACE, "%s(%d):    => av is %s\n", __func__, __LINE__,
+           (av == IARF_IGNORE) ? "IGNORE" :
+           (av == IARF_ADD) ? "ADD" :
+           (av == IARF_REMOVE) ? "REMOVE" : "FORCE");
    switch (av)
    {
    case IARF_ADD:
@@ -2638,8 +2733,16 @@ size_t space_col_align(chunk_t *first, chunk_t *second)
    case IARF_REMOVE:
       break;
 
-   case IARF_IGNORE:
-      if (second->orig_col > (first->orig_col + first->len()))
+   case IARF_IGNORE:                // Issue #2064
+      LOG_FMT(LSPACE, "%s(%d):    => first->orig_line  is %zu\n", __func__, __LINE__, first->orig_line);
+      LOG_FMT(LSPACE, "%s(%d):    => second->orig_line is %zu\n", __func__, __LINE__, second->orig_line);
+      LOG_FMT(LSPACE, "%s(%d):    => first->text()     is '%s'\n", __func__, __LINE__, first->text());
+      LOG_FMT(LSPACE, "%s(%d):    => second->text()    is '%s'\n", __func__, __LINE__, second->text());
+      LOG_FMT(LSPACE, "%s(%d):    => first->orig_col   is %zu\n", __func__, __LINE__, first->orig_col);
+      LOG_FMT(LSPACE, "%s(%d):    => second->orig_col  is %zu\n", __func__, __LINE__, second->orig_col);
+      LOG_FMT(LSPACE, "%s(%d):    => first->len()      is %zu\n", __func__, __LINE__, first->len());
+      if (  first->orig_line == second->orig_line
+         && second->orig_col > (first->orig_col + first->len()))
       {
          coldiff++;
       }
@@ -2649,7 +2752,7 @@ size_t space_col_align(chunk_t *first, chunk_t *second)
       // If we got here, something is wrong...
       break;
    }
-   LOG_FMT(LSPACE, "   => coldiff is %zu\n", coldiff);
+   LOG_FMT(LSPACE, "%s(%d):    => coldiff is %zu\n", __func__, __LINE__, coldiff);
    return(coldiff);
 } // space_col_align
 
@@ -2657,10 +2760,6 @@ size_t space_col_align(chunk_t *first, chunk_t *second)
 void space_add_after(chunk_t *pc, size_t count)
 {
    LOG_FUNC_ENTRY();
-   //if (count <= 0)
-   //{
-   //   return;
-   //}
 
    chunk_t *next = chunk_get_next(pc);
 
@@ -2700,6 +2799,7 @@ void space_add_after(chunk_t *pc, size_t count)
    sp.pp_level    = pc->pp_level;
    sp.column      = pc->column + pc->len();
    sp.orig_line   = pc->orig_line;
+   sp.orig_col    = pc->orig_col;
 
    chunk_add_after(&sp, pc);
 } // space_add_after
