@@ -1,14 +1,16 @@
 /**
  * @file unc_tools.h
  *
- * @author  Guy Maurel since version 0.62 for uncrustify4Qt
- *          October 2015, 2016
+ * @author  Guy Maurel
+ *          October 2015, 2016, 2017, 2018, 2019
  * @license GPL v2+
  */
 
 #ifndef UNC_TOOLS_H_INCLUDED
 #define UNC_TOOLS_H_INCLUDED
 
+//#define DEVELOP_ONLY
+#ifdef DEVELOP_ONLY
 #include "prototypes.h"
 #include "uncrustify_types.h"
 #include "chunk_list.h"
@@ -31,4 +33,5 @@ void dump_out(unsigned int type);
 void dump_in(unsigned int type);
 
 
+#endif /* DEVELOP_ONLY */
 #endif /* UNC_TOOLS_H_INCLUDED */
