@@ -12,6 +12,9 @@
 #include "uncrustify.h"
 
 #include "align.h"
+#include "align_nl_cont.h"
+#include "align_preprocessor.h"
+#include "align_trailing_comments.h"
 #include "args.h"
 #include "backup.h"
 #include "brace_cleanup.h"
@@ -246,8 +249,8 @@ void usage(const char *argv0)
            "\n"
            "Errors are always dumped to stderr\n"
            "\n"
-           "The '-f' and '-o' options may not be used with '-F', '--replace' or '--no-backup'.\n"
-           "The '--prefix' and '--suffix' options may not be used with '--replace' or '--no-backup'.\n"
+           "The '-f' and '-o' options may not be used with '-F' or '--replace'.\n"
+           "The '--prefix' and '--suffix' options may not be used with '--replace'.\n"
            "\n"
            "Basic Options:\n"
            " -c CFG       : Use the config file CFG.\n"
@@ -262,7 +265,7 @@ void usage(const char *argv0)
            " --suffix SFX : Append SFX to the output filename. The default is '.uncrustify'\n"
            " --prefix PFX : Prepend PFX to the output filename path.\n"
            " --replace    : Replace source files (creates a backup).\n"
-           " --no-backup  : Replace files, no backup. Useful if files are under source control.\n"
+           " --no-backup  : Do not create backup and md5 files. Useful if files are under source control.\n"
            " --if-changed : Write to stdout (or create output FILE) only if a change was detected.\n"
 #ifdef HAVE_UTIME_H
            " --mtime      : Preserve mtime on replaced files.\n"
@@ -305,11 +308,11 @@ void usage(const char *argv0)
            "      processing of parts of the source file (these can be overridden with\n"
            "      enable_processing_cmt and disable_processing_cmt).\n"
            "\n"
-           "There are currently %zd options and minimal documentation.\n"
+           "There are currently %d options and minimal documentation.\n"
            "Try UniversalIndentGUI and good luck.\n"
            "\n"
            ,
-           path_basename(argv0), get_option_count());
+           path_basename(argv0), (int)get_option_count());
 } // usage
 
 
@@ -529,7 +532,14 @@ int main(int argc, char *argv[])
    if (  ((parsed_file = arg.Param("--parsed")) != nullptr)
       || ((parsed_file = arg.Param("-p")) != nullptr))
    {
-      LOG_FMT(LNOTE, "Will export parsed data to: %s\n", parsed_file);
+      if (parsed_file[0] == '-' && !parsed_file[1])
+      {
+         LOG_FMT(LNOTE, "Will print parsed data to stdout\n");
+      }
+      else
+      {
+         LOG_FMT(LNOTE, "Will export parsed data to: %s\n", parsed_file);
+      }
    }
 
    // Enable log severities
@@ -627,7 +637,7 @@ int main(int argc, char *argv[])
 
    if (!cpd.do_check)
    {
-      if (replace || no_backup)
+      if (replace)
       {
          if (prefix != nullptr || suffix != nullptr)
          {
@@ -636,7 +646,7 @@ int main(int argc, char *argv[])
          }
          if (source_file != nullptr || output_file != nullptr)
          {
-            usage_error("Cannot use --replace or --no-backup with -f or -o");
+            usage_error("Cannot use --replace with -f or -o");
             return(EX_NOINPUT);
          }
       }
@@ -651,8 +661,8 @@ int main(int argc, char *argv[])
 
    /*
     * Try to load the config file, if available.
-    * It is optional for "--universalindent" and "--detect", but required for
-    * everything else.
+    * It is optional for "--universalindent", "--parsed" and "--detect", but
+    * required for everything else.
     */
    if (!cfg_file.empty())
    {
@@ -794,10 +804,10 @@ int main(int argc, char *argv[])
    }
 
    /*
-    * Everything beyond this point requires a config file, so complain and
-    * bail if we don't have one.
+    * Everything beyond this point aside from dumping the parse tree is silly
+    * without a config file, so complain and bail if we don't have one.
     */
-   if (cfg_file.empty())
+   if (cfg_file.empty() && !parsed_file)
    {
       usage_error("Specify the config file with '-c file' or set UNCRUSTIFY_CONFIG");
       return(EX_IOERR);
@@ -1582,7 +1592,7 @@ static void add_func_header(c_token_t type, file_mem &fm)
       while ((ref = chunk_get_prev(ref)) != nullptr)
       {
          // Bail if we change level or find an access specifier colon
-         if (ref->level != pc->level || chunk_is_token(ref, CT_PRIVATE_COLON))
+         if (ref->level != pc->level || chunk_is_token(ref, CT_ACCESS_COLON))
          {
             do_insert = true;
             break;
@@ -2043,11 +2053,22 @@ void uncrustify_file(const file_mem &fm, FILE *pfout,
    // Special hook for dumping parsed data for debugging
    if (parsed_file != nullptr)
    {
-      FILE *p_file = fopen(parsed_file, "wb");
+      FILE *p_file;
+      if (parsed_file[0] == '-' && !parsed_file[1])
+      {
+         p_file = stdout;
+      }
+      else
+      {
+         p_file = fopen(parsed_file, "wb");
+      }
       if (p_file != nullptr)
       {
          output_parsed(p_file);
-         fclose(p_file);
+         if (p_file != stdout)
+         {
+            fclose(p_file);
+         }
       }
       else
       {
