@@ -1528,8 +1528,8 @@ EMSCRIPTEN_BINDINGS(MainModule)
       .value(STRINGIFY(CT_NEW), CT_NEW)
       .value(STRINGIFY(CT_OPERATOR), CT_OPERATOR)
       .value(STRINGIFY(CT_OPERATOR_VAL), CT_OPERATOR_VAL)
-      .value(STRINGIFY(CT_PRIVATE), CT_PRIVATE)
-      .value(STRINGIFY(CT_PRIVATE_COLON), CT_PRIVATE_COLON)
+      .value(STRINGIFY(CT_ACCESS), CT_ACCESS)
+      .value(STRINGIFY(CT_ACCESS_COLON), CT_ACCESS_COLON)
       .value(STRINGIFY(CT_THROW), CT_THROW)
       .value(STRINGIFY(CT_NOEXCEPT), CT_NOEXCEPT)
       .value(STRINGIFY(CT_TRY), CT_TRY)
